library(tidyverse)
library(infer)

# The same code is provided below for 95% Bootstrapped Simulation-based  tests for each of the soda company examples.
# Leave the sample you want to test un-commented.

soda_sample <- read_csv("http://www.cknuckles.com/statsprogramming/data/soda_sample_largess.csv")
#soda_sample <- read_csv("http://www.cknuckles.com/statsprogramming/data/soda_sample_veracious.csv")
#soda_sample <- read_csv("http://www.cknuckles.com/statsprogramming/data/soda_sample_curmudgeon.csv")

ggplot(data = soda_sample, mapping = aes(x = ounces)) +
  geom_histogram(bins=20, color = "white")

# Sample Stats
sample_stats <- soda_sample %>%
  summarize(
    sample_mean = mean(ounces),
  )

xbar <- sample_stats$sample_mean
xbar


# Null Distribution
null_dist <- soda_sample %>%
  specify(response = ounces) %>%
  hypothesize(null = "point", mu = 12) %>%          # The NULL HYP
  generate(reps = 10000, type = "bootstrap") %>%    # Bootstrap Null Distribution
  calculate(stat = "mean")

# Not enough decimal accuracy in standard tibble print view
# null_dist
print.data.frame(null_dist)

# Null Distribution Stats
boot_stats <- null_dist %>%
  summarize(
    boot_dist_mean = mean(stat),
    boot_dist_SE = sd(stat)
  )
boot_stats


# Null Hypothesis: μ = 12
# Alternative Hypothesis:  μ ≠ 12
########################################################################################


# p-value
p <- null_dist %>%
  get_p_value(obs_stat = xbar , direction = "two_sided")
p

# 95% CI (Bootstrap SE method)
ci <- null_dist %>%
  get_ci(level = .95, type = "se", point_estimate = xbar)
#ci

# Not enough decimal accuracy in standard tibble print vies
# ci
print.data.frame(ci)

# Bootstrap Distribution with shaded p-value
null_dist %>%
  visualize() +
  shade_p_value(obs_stat = xbar, direction = "two_sided") +
  labs(x = "Bootstrap Sample Means")

# Bootstrap Distribution with shaded 95% CI
null_dist %>%
  visualize() +
  shade_p_value(obs_stat = xbar, direction = "two_sided", fill = "#606060") + # fill color match-just want the xbar line
  shade_ci(endpoints = ci) +
  labs(x = "Bootstrap Sample Means")

