library(tidyverse)
library(infer)

die_rolls <- read_csv("http://www.cknuckles.com/statsprogramming/data/die_rolls.csv")
die_rolls

die_rolls %>%
  group_by(roll) %>%
  tally()      # Shortcut for summarize( n=n() )


# Need categorical column with 2 values, one of which is SUCCESS for Binomial
die_rolls_wrangled <- die_rolls %>%
  mutate(is_6 = (roll==6))
die_rolls_wrangled


# Null Distribution
null_dist_draw <- die_rolls_wrangled %>%
  specify(response = is_6, success = "TRUE") %>%
  hypothesize(null = "point", p = 1/6) %>%       # The NULL HYP
  generate(reps = 10000, type="draw") %>%        # Random Draw Null Distribution
  calculate(stat = "prop")

ggplot(data = null_dist_draw, mapping = aes(x = stat)) +
  geom_histogram(bins=30, color = "white")


# Null Distribution Stats
null_dist_draw %>%
  summarize(
    draw_dist_mean = mean(stat),
    draw_dist_SE = sd(stat)
  )


# Null Hypothesis: p = 1/6
# Alternative Hypothesis:  p ≠ 1/6
########################################################################################



null_dist_draw %>%
  get_p_value(obs_stat = .176 , direction = "two_sided")

# Observed sample proportion with shaded p-value
null_dist_draw %>%
  visualize() +
  shade_p_value(obs_stat = .176, direction = "two_sided")
