library(tidyverse)
library(infer)

# Test Data with Two Categories
test_table <- tibble(
  category = c('A','A','A','A','A','B','B','B','B','B'),
  value = 1:10
)
test_table

# Data Visualization and Stats for the test data
ggplot(data = test_table, aes(x = category, y = value)) +
  geom_boxplot()

test_table %>%
  group_by(category) %>%
  summarize(
    category_mean = mean(value)
  )


# 10,000 permutation re-samples
permutation_re_samples <- test_table %>%
  specify(response = value, explanatory = category) %>%
  hypothesize(null = "independence") %>%
  generate(reps = 10000, type = "permute")
permutation_re_samples

# Each replicate - permutations change the mean of each category
permutation_re_samples %>%
  group_by(replicate,category) %>%
  summarize(
    category_mean = mean(value)
  )

# Simulation for Null Distribution
perm_null_dist <- permutation_re_samples %>%
  calculate(stat = "diff in means", order = c("B", "A"))
perm_null_dist

perm_null_dist %>%
  summarize(
    average_difference_across_all_replicates = mean(stat)
  )

# Handy histogram-drawing function that comes with Infer package
visualize(perm_null_dist)
