library(tidyverse)
library(infer)

library(ggplot2movies)  # Over 58,000 movie records (rows)

movies

# Drop records that have NA ratings OR budget
movies_with_budget <-  movies %>%
  filter(votes>=500 & year>=1970 & length>=70) %>%
  drop_na(rating,budget)

summary(movies_with_budget$rating)
summary(movies_with_budget$budget)

# For a proportion, both the response and explanatory variables
# will need to have exactly two categories as shown below

# null_dist_movie_budget <- movies_data_categorical %>%
#   specify(response = rating_level, success = "Good_Rating", explanatory = budget_level) %>%
#   hypothesize(null = "independence") %>%
#   generate(reps = 10000, type = "permute") %>%
#  calculate(stat = "diff in props", order = c("High_Budget","Low_Budget"))



movies_data_categorical <- movies_with_budget %>%
  mutate(
    rating_level = case_when(
      (rating >= 6.3) ~ 'Good_Rating',
      (rating < 6.3) ~ 'Bad_Rating'
    ),
    budget_level = case_when(
      (budget >= 17000000) ~ 'High_Budget',
      (budget < 17000000) ~ 'Low_Budget'
    )
  ) %>%
  select(title,rating_level,budget_level)

movies_data_categorical %>%
  slice_sample(n=10)


ggplot(movies_data_categorical, aes(x = budget_level, fill = rating_level)) +
  geom_bar()


movies_data_categorical %>%
  specify(response = rating_level, success = "Good_Rating", explanatory = budget_level) %>%
  calculate(stat = "diff in props", order = c("High_Budget","Low_Budget"))


# Diff of Means Test
# Null Hypothesis:         p_1 - p_2 = 0
# Alternative Hypothesis:  p_1 - p_2 ≠ 0
########################################################################################


# Calculate the Simulation-Based Null Distribution
null_dist_movie_budget <- movies_data_categorical %>%
  specify(response = rating_level, success = "Good_Rating", explanatory = budget_level) %>%
  hypothesize(null = "independence") %>%
  generate(reps = 10000, type = "permute") %>%
  calculate(stat = "diff in props", order = c("High_Budget","Low_Budget"))

# Calculate p-value
null_dist_movie_budget %>%
  get_p_value(obs_stat = -.102, direction = "two_sided")

# Helpful visualization of Null Distribution and p-value
visualize(null_dist_movie_budget) +
  shade_p_value(obs_stat = -.102, direction = "two_sided")
